==> central-repository-3.63.0.zip: ej/sni/NativeException.java <==
/*
 * Java
 *
 * Copyright 2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.sni;


/**
 * {@link RuntimeException} subclass that may be thrown from an SNI native using
 * <code>SNI_throwNativeException()</code> function.
 */
public class NativeException extends RuntimeException {


	/**
	 * Constructs a new {@link NativeException} with the specified error code and detail
	 * message.
	 * 
	 * @param errorCode the error code. The error code is saved for later retrieval by
	 * the {@link #getErrorCode()} method.
	 * 
	 * @param errorMessage the detail message. The detail message is saved for later retrieval
	 * by the {@link #getMessage()} method.
	 */
	public NativeException(int errorCode, String errorMessage){
		throw new RuntimeException();
	}

	/**
	 * Constructs a new {@link NativeException} with the specified error code, detail message and cause.
	 * 
	 * @param errorCode the error code. The error code is saved for later retrieval by
	 * the {@link #getErrorCode()} method.
	 * 
	 * @param errorMessage the detail message. The detail message is saved for later retrieval
	 * by the {@link #getMessage()} method.
	 * 
	 * @param cause the cause (which is saved for later retrieval by the {@link #getCause()} method).
	 * (A <tt>null</tt> value is permitted, and indicates that the cause is nonexistent or unknown.)
	 */
	public NativeException(int errorCode, String errorMessage, Throwable cause){
		throw new RuntimeException();
	}

	/**
	 * Returns the detail message string of this {@link NativeException}.
	 * 
	 * @return the detail message string of this {@link NativeException} instance (which may be
	 *         {@code null}).
	 */
	public String getMessage() {
		throw new RuntimeException();
	}

	/**
	 * Returns the error code of this {@link NativeException}.
	 * @return the error code of this {@link NativeException} instance.
	 */
	public int getErrorCode(){
		throw new RuntimeException();
	}
}

==> central-repository-3.64.0.zip: ej/sni/NativeException.java <==
/*
 * Java
 *
 * 2017-2022 ESR - Not subject to Copyright.
 *
 * This document has been released and published by E-S-R consortium, a non-profit entity.
 * To learn more about E-S-R consortium, please visit http://www.e-s-r.net/.
 * The matter contained in this document is not subject to copyright; you are free to use it for any purpose, for more information see E-S-R consortium policies.
 */
package ej.sni;

import ej.annotation.Nullable;

/**
 * {@link RuntimeException} subclass that may be thrown from an SNI native using
 * <code>SNI_throwNativeException()</code> function.
 */
public class NativeException extends RuntimeException {


	/**
	 * Constructs a new {@link NativeException} with the specified error code and detail
	 * message.
	 *
	 * @param errorCode the error code. The error code is saved for later retrieval by
	 * the {@link #getErrorCode()} method.
	 *
	 * @param errorMessage the detail message. The detail message is saved for later retrieval
	 * by the {@link #getMessage()} method.
	 */
	public NativeException(int errorCode, String errorMessage){
		throw new RuntimeException();
	}

	/**
	 * Constructs a new {@link NativeException} with the specified error code, detail message and cause.
	 *
	 * @param errorCode the error code. The error code is saved for later retrieval by
	 * the {@link #getErrorCode()} method.
	 *
	 * @param errorMessage the detail message. The detail message is saved for later retrieval
	 * by the {@link #getMessage()} method.
	 *
	 * @param cause the cause (which is saved for later retrieval by the {@link #getCause()} method).
	 * (A <tt>null</tt> value is permitted, and indicates that the cause is nonexistent or unknown.)
	 */
	public NativeException(int errorCode, String errorMessage, @Nullable Throwable cause) {
		throw new RuntimeException();
	}

	/**
	 * Returns the detail message string of this {@link NativeException}.
	 *
	 * @return the detail message string of this {@link NativeException} instance (which may be
	 *         {@code null}).
	 */
	@Override
	@Nullable
	public String getMessage() {
		throw new RuntimeException();
	}

	/**
	 * Returns the error code of this {@link NativeException}.
	 * @return the error code of this {@link NativeException} instance.
	 */
	public int getErrorCode(){
		throw new RuntimeException();
	}
}
